import 'package:get/get.dart';
import 'package:uuid/uuid.dart';

class StatusController extends GetxController {
  static Duration delayForCompletion = Duration(milliseconds: 500);

  RxList<DartError> _exceptions = <DartError>[].obs;

  RxSet<Uuid> processes = <Uuid>{}.obs;

  bool get isProcessing => processes.isNotEmpty;

  void add(Uuid uuid) {
    processes.add(uuid);
  }

  void complete(Uuid uuid) {
    processes.remove(uuid);
  }

  bool get hasError => _exceptions.isNotEmpty;

  DartError? currentError() => _exceptions.isEmpty ? null : _exceptions.first;

  void catchError(dynamic error) {
    _exceptions.add(DartError(error));
  }

  void consumeError(DartError error) {
    _exceptions.removeWhere((element) => element.uuid == error.uuid);
  }
}

class DartError {
  dynamic error;
  String uuid = Uuid().v4();

  DartError(this.error);

  @override
  bool operator ==(Object other) =>
      (other is DartError) ? uuid == other.uuid : false;

  @override
  String toString() => error.toString();
}
